@@ -1,33 +1,36 @@
+extern crate alloc;
+
+use alloc::fmt::format;
 use cortex_m::iprint;
 use stm32f1xx_hal_bxcan::pac::ITM;
 
 #[macro_export]
 macro_rules! log_debug {
     ($logger:expr, $fmt:expr) => {
-        logger.log_debug($fmt);
+        $logger.log_debug($fmt);
     };
     ($logger:expr, $fmt:expr, $($arg:tt)*) => {
-        logger.log_debug(format!($fmt, $($arg)*));
+        $logger.log_debug(format!($fmt, $($arg)*));
     };
 }
 
 #[macro_export]
 macro_rules! log_warning {
     ($logger:expr, $fmt:expr) => {
-        logger.log_warning($fmt);
+        $logger.log_warning($fmt);
     };
     ($logger:expr, $fmt:expr, $($arg:tt)*) => {
-        logger.log_warning(format!($fmt, $($arg)*));
+        $logger.log_warning(format!($fmt, $($arg)*));
     };
 }
 
 #[macro_export]
 macro_rules! log_error {
     ($logger:expr, $fmt:expr) => {
-        logger.log_error($fmt);
+        $logger.log_error($fmt);
     };
     ($logger:expr, $fmt:expr, $($arg:tt)*) => {
-        logger.log_error(format!($fmt, $($arg)*));
+        $logger.log_error(format!($fmt, $($arg)*));
     };
 }
 
@@ -44,10 +47,7 @@ pub struct RossLogger {
 
 impl RossLogger {
     pub fn new(log_level: RossLogLevel, itm: ITM) -> Self {
-        RossLogger {
-            log_level,
-            itm
-        }
+        RossLogger { log_level, itm }
     }
 
     pub fn change_log_level(&mut self, log_level: RossLogLevel) {
@@ -63,7 +63,9 @@ impl RossLogger {
     }
 
     pub fn log_warning(&mut self, message: &str) {
-        if matches!(self.log_level, RossLogLevel::Debug) || matches!(self.log_level, RossLogLevel::Warning) {
+        if matches!(self.log_level, RossLogLevel::Debug)
+            || matches!(self.log_level, RossLogLevel::Warning)
+        {
             self.log("[DEBUG] ");
             self.log(message);
             self.log("\r\n");
